TODO...
-------

- Print sorted output.
- Add info to results report:

  - Brightness;
  - flatness (SA - SB)/SA - fluorescence is constant? GREAT;
  - presence of isosbestic (the fitting line cross / SA1 < SB1 and SA2 > SB2
    sometime they do not cross anyway).
- Robust fit considering sigma pH.
- check metadata and report the diff REMEMBER 8.8 (2013-05-29); metadata
  rescaled; dataframe groupby per meta_pre, ma anche enspire
